# cs207-FinalProject

[![Build Status](https://travis-ci.com/ADMonsters/cs207-FinalProject.svg?branch=master)](https://travis-ci.com/ADMonsters/cs207-FinalProject)

[![codecov](https://codecov.io/gh/ADMonsters/cs207-FinalProject/branch/master/graph/badge.svg)](https://codecov.io/gh/ADMonsters/cs207-FinalProject)

## Group 2

- Benjamin Levy
- Mark Miao
- Zhenru Wang
- Kidus Negesse

## A guide for using this package can be found in docs/milestone2.ipynb